﻿using System;
using System.Collections.Generic;
using System.Text;
//step1. reference nmodbuspc.dll, and using the namespaces.
using Modbus.Device;      //for modbus master
using System.IO.Ports;    //for controlling serial ports
using System.Net.Sockets;


namespace input_register
{
    class Program
    {
        static void Main(string[] args)
        {
            
            // create a new SerialPort object with default settings.
            SerialPort serialPort = new SerialPort();

            // set the appropriate properties.
            serialPort.PortName = "COM1";   //the COM port connected to WISE COM1(RS-232)
            serialPort.BaudRate = 115200;
            serialPort.Parity = Parity.None;
            serialPort.StopBits = StopBits.One;
            serialPort.DataBits = 8;            
            serialPort.Open();
          
            // create Modbus RTU Master by the comport client
            //document->Modbus.Device.Namespace->ModbusSerialMaster Class->CreateRtu Method
            ModbusSerialMaster master = ModbusSerialMaster.CreateRtu(serialPort);

            // read the input register 20~29 (30020~30029, AI ch0 ~ ch4, float type) of the WISE module.
            //document->Modbus.Device.Namespace->ModbusMaster Class->ReadInputRegisters Method
            byte slaveID = 1;
            ushort startAddress = 20;
            ushort numOfPoints = 10;
            master.Transport.ReadTimeout = 300;
            try
            {
                ushort[] register = master.ReadInputRegisters(slaveID, startAddress, numOfPoints);
                float[] floatData = new float[register.Length / 2];
                Buffer.BlockCopy(register, 0, floatData, 0, register.Length * 2);
                for (int index = 0; index < floatData.Length; index++)
                    Console.WriteLine(string.Format("AI[{0}] = {1}", index, floatData[index]));
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }

            Console.WriteLine("Press enter to exit....");
            Console.ReadLine();
        }
    }
}
